#![doc = include_str!("../Readme.md")]

/// A macro to create a new graphics shape.
pub type Point = shape_core::Point<f32>;
/// A circle defined by center and radius.
pub type Circle = shape_core::Circle<f32>;
/// An ellipse defined by center and axes.
pub type Ellipse = shape_core::Ellipse<f32>;

#[doc(inline)]
pub type Line = shape_core::Line<f32>;

pub type Square = shape_core::Square<f32>;
pub type Rectangle = shape_core::Rectangle<f32>;

pub type Triangle = shape_core::Triangle<f32>;
pub type Polygon = shape_core::Polygon<f32>;
pub type Polyline = shape_core::Polyline<f32>;
pub type RegularPolygon = shape_core::RegularPolygon<f32>;
